ConfigError

Enum ConfigError 

#[non_exhaustive]
pub enum ConfigError { UnsupportedFormat(String), MissingExtension, MissingValue { field: String, span: Option<SourceSpan>, }, TypeMismatch { field: String, expected: String, found: String, span: Option<SourceSpan>, }, Nested { section: String, source: Box<dyn Diagnostic + Send + Sync>, span: Option<SourceSpan>, }, Io(Error), Toml { source: Error, span: Option<SourceSpan>, }, }
Unified error returned by the runtime components.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnsupportedFormat(String)

The format chosen by the caller or inferred from the extension is not supported.



MissingExtension

File paths without an extension cannot be parsed automatically.



MissingValue

Raised when a required value is not found during deserialization.

Fields

field: String

The field name that is missing

span: Option<SourceSpan>

Optional source span for where the error occurred



TypeMismatch

Raised when a value cannot be converted into the expected target type.

Fields

field: String

The field name that has the wrong type

expected: String

The expected type

found: String

The found value or type

span: Option<SourceSpan>

Optional source span highlighting the problematic value



Nested

Used to thread contextual errors when deserializing nested structs.

Fields

section: String

The section name that failed

source: Box<dyn Diagnostic + Send + Sync>

The underlying error

span: Option<SourceSpan>

Optional source span for the section



Io(Error)

IO errors propagated from the filesystem.



Toml

TOML parsing failure.

Fields

source: Error

The underlying toml error

span: Option<SourceSpan>

Optional source span for where the parse error occurred

Implementations

Source

impl ConfigError

pub fn mismatch( field: impl Into<String>, expected: impl Into<String>, found: impl Into<String>, ) -> Self

Helper to produce a TypeMismatch error.

pub fn mismatch_at( field: impl Into<String>, expected: impl Into<String>, found: impl Into<String>, span: SourceSpan, ) -> Self

Helper to produce a TypeMismatch error with a source span.

pub fn nested(section: impl Into<String>, source: ConfigError) -> Self

Helper to wrap nested errors with additional context.

pub fn nested_at( section: impl Into<String>, source: ConfigError, span: SourceSpan, ) -> Self

Helper to wrap nested errors with additional context and a source span.

pub fn missing(key: impl Into<String>) -> Self

Helper to surface missing values.

pub fn missing_at(key: impl Into<String>, span: SourceSpan) -> Self

Helper to surface missing values with a source span.